pifacerelayplus
===============
The PiFace Relay Plus module.


Documentation
=============
[http://pifacerelayplus.readthedocs.org/](http://pifacerelayplus.readthedocs.org/)

You can also find the documentation and some examples installed at:

    /usr/share/doc/python3-pifacerelayplus/


Install
=======
Aptitude
--------
Try this first:

    sudo apt-get update
    sudo apt-get install python{,3}-pifacerelayplus

Debian Package
--------------
Download the debian package from [here](https://github.com/piface/pifacerelayplus/releases) and install with:

    $ dpkg -i python3-pifacerelayplus-0.2.0-1_all.deb

You may need to download and install the latest release of
[pifacecommon](https://github.com/piface/pifacecommon/releases) and reboot.
